summaryrefslogtreecommitdiff
path: root/indra/newview/llwldaycycle.h
diff options
context:
space:
mode:
authorVadim ProductEngine <vsavchuk@productengine.com>2011-05-30 22:34:56 +0300
committerVadim ProductEngine <vsavchuk@productengine.com>2011-05-30 22:34:56 +0300
commit657e434fd59139436e8b97e5ecd01ca686e82269 (patch)
treebebf0c4c8adff3587cec47f6403757f841f5c872 /indra/newview/llwldaycycle.h
parent6f1cdd4926444567d21b1d6e0735a445b981e56b (diff)
STORM-1253 WIP New day cycle editor.
Done: * Creating new local day cycles. * Editing existing local day cycles. * Deleting day cycles. To do: * Editing region day cycle, dealing with skies in region scope. * Handle teleport while editing a day cycle. * Update UI when a day cycle or sky preset gets deleted. * Make the time ctrl increase/decrease consistently.
Diffstat (limited to 'indra/newview/llwldaycycle.h')
-rw-r--r--indra/newview/llwldaycycle.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/indra/newview/llwldaycycle.h b/indra/newview/llwldaycycle.h
index 56bd66f114..e5bc82bb6c 100644
--- a/indra/newview/llwldaycycle.h
+++ b/indra/newview/llwldaycycle.h
@@ -62,9 +62,12 @@ public:
/// load a day cycle
void loadDayCycleFromFile(const std::string & fileName);
/// load a day cycle
void saveDayCycle(const std::string & fileName);
+ /// save a day cycle
+ void save(const std::string& file_path);
+
/// load the LLSD data from a file (returns the undefined LLSD if not found)
static LLSD loadCycleDataFromFile(const std::string & fileName);
@@ -62,9 +62,12 @@ public:
/// load a day cycle
void loadDayCycleFromFile(const std::string & fileName);
- /// load a day cycle
+ /// save a day cycle
void saveDayCycle(const std::string & fileName);